package com.persagy.cache;

import org.springframework.stereotype.Component;

import java.util.concurrent.ConcurrentHashMap;

/**
 * @description: 实时数据
 * @author: feng
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/7/16 15:50
 * @version: V1.0
 */
@Component
public class CurrentDataCache {

    private ConcurrentHashMap<String, Double> latestIOTDataMap = new ConcurrentHashMap<>();

    /**
     * @description:获取设备实时数据
     * @exception:
     * @author: LuoGuangyi
     * @company: Persagy Technology Co.,Ltd
     * @param meterId: 表号
     * @param funcId: 功能号
     * @return: java.lang.String
     * @since: 2020/10/19 16:15
     * @version: V1.0
     */
    public double getCurrentData(String meterId, String funcId) {
        return latestIOTDataMap.get(getKey(meterId, funcId));
    }

    private String getKey(String meterId,String funcId) {
        return meterId + "-" + funcId;
    }

    /**
     * @description:存放实时数据
     * @exception:
     * @author: LuoGuangyi
     * @company: Persagy Technology Co.,Ltd
     * @param meterId: 表号
     * @param funcId: 功能号
     * @param currentData: 当前值
     * @return: void
     * @since: 2020/10/19 16:16
     * @version: V1.0
     */
    public void putCurrentData(String meterId, String funcId, double currentData) {
        latestIOTDataMap.put(getKey(meterId,funcId), currentData);
    }

    /**
     * @description:判断是否包含有改表号功能号的数据
     * @exception:
     * @author: LuoGuangyi
     * @company: Persagy Technology Co.,Ltd
     * @param meterId:表号
     * @param funcId:功能号
     * @return: boolean
     * @since: 2020/10/19 19:54
     * @version: V1.0
     */
    public boolean hasKey(String meterId,String funcId) {
        return latestIOTDataMap.containsKey(getKey(meterId,funcId));
    }
}
