package com.persagy.entity;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import lombok.Data;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import java.util.List;

@Data
@NoArgsConstructor
public class NettyMessage<T> {
    /*
    唯一标识
     */
    @JSONField()
    private long streamId;
    @JSONField()
    private int version = 1;
    /**
     * 操作类型：1-请求、2 -响应、3-通知、
     * 4-边缘端获取报警定义、
     * 5-边缘端主动推送报警记录、
     * 6-边缘端主动更新报警记录状态、
     * 7-云端推送修改的报警定义给边缘端(增量新增修改报警定义)、
     * 8-云端把报警记录的id推送到边缘端
     * 9-边缘端取报警定义，云端推送给边缘端的标记(全量报警定义)
     * 10-云端推送删除的报警定义给边缘端(增量删除报警定义)、
     * 200 - 建立连接，此时的source == 项目id
     */
    @JSONField()
    private int opCode;
    /**
    请求来源
     */
    @JSONField()
    private String source = "project";

    /**
    传输内容
     */
    @JSONField(jsonDirect=true)
    private List<T> content;
    /**
     * 备注说明
     */
    @JSONField()
    private String remark;

    /**
    成功标识
     */
    @JSONField()
    private Boolean success;

    public List<T> getContent() {
        return content;
    }

    public void setContent(List<T> content) {
        this.content = content;
    }

    public NettyMessage(int opCode, String source) {
        this.opCode = opCode;
        this.source = source;
    }

    public NettyMessage(String source) {
        this.source = source;
    }

    @Override
    public String toString() {
        return JSONObject.toJSONString(this);
    }
}
