package com.persagy.entity;


import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 * 报警记录
 */
@ApiModel(value = "报警记录")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Entity
@Table(name = "zkt_alarm_record")
public class ZktAlarmRecordDO implements Serializable {
    private static final long serialVersionUID = 1L;
    /**
     * 报警定义ID
     */
    @Id
//    @GeneratedValue(strategy = GenerationType.IDENTITY) // strategy 设置使用数据库主键自增策略；
//            ,generator = "JDBC") // generator 设置插入完成后，查询最后生成的 ID 填充到该属性中。
    @Column(name = "definition_id", nullable = false)
    private String definitionId;

    /**
     * 报警条目编码
     */
    @Column(name = "item_code", nullable = false)
    @ApiModelProperty(value = "报警条目编码")
    private String itemCode;

    /**
     * 报警对象ID
     */
    @Column(name = "obj_id", nullable = false)
    @ApiModelProperty(value = "报警对象ID")
    private String objId;

    /**
     * 报警定义对应最新一条报警记录状态
     * 1-产生 2-恢复 3-过期
     */
    @Column(name = "state")
    @ApiModelProperty(value = "报警定义对应最新一条报警记录状态")
    private String state;

    /**
     * 报警定义对应最新一条报警记录ID
     */
    @Column(name = "alarm_id")
    @ApiModelProperty(value = "报警定义对应最新一条报警记录ID")
    private String alarmId;

    /**
     * 报警时间
     */
    @Column(name = "alarm_time")
    @ApiModelProperty(value = "报警时间")
    private String alarmTime;

    /**
     * 报警生效结束时间(报警过期时间)
     */
    @Column(name = "effect_end_time")
    @ApiModelProperty(value = "报警生效结束时间(报警过期时间)")
    private String effectEndTime;

    /**
     * 备注
     */
    @Column(name = "remark")
    @ApiModelProperty(value = "备注")
    private String remark;

    /**
     * 报警名称
     */
    @Column(name = "name")
    @ApiModelProperty(value = "报警名称")
    private String name;

    /**
     * 报警结束值
     */
    @ApiModelProperty(value = "报警结束值")
    @JSONField(jsonDirect = true)
    private String endInfo;

    /**
     * 有效期结束时间
     */
    @ApiModelProperty(value = "报警自动过期时间")
    private Date endTime;

    @Override
    public String toString() {
        return JSONObject.toJSONString(this);
    }

}