package com.persagy.job;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.date.TimeInterval;
import com.persagy.client.GroupNettyClient;
import com.persagy.entity.NettyMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import java.util.Objects;

/**
 * @author LuoGuangyi
 * @title: SpringSchedule
 * @projectName spring-boot-examples
 * @description: TODO
 * @date 2019/09/17 16:54
 */

@Service
@Slf4j
public class SpringSchedule {
    @Autowired
    GroupNettyClient groupNettyClient;

    @Scheduled(cron="${alarm.get.all.alarmdefine.cron}")
    public void allResetCron() throws InterruptedException {
        NettyMessage message = new NettyMessage(4,groupNettyClient.projectId);
        groupNettyClient.sendMessage(message.toString());
    }


    @Scheduled(initialDelay=1000, fixedRate=600000)
    public void connectAnalizeCron() {
        if(Objects.isNull(GroupNettyClient.channelGroup)) {
            log.warn("NettyClient is not init");
            return;
        }
        log.info("NettyClient State:isActive[{}],isOpen[{}],isRegistered[{}],isWritable[{}]",GroupNettyClient.channelGroup.isActive(),GroupNettyClient.channelGroup.isOpen(),GroupNettyClient.channelGroup.isRegistered(),GroupNettyClient.channelGroup.isWritable());
        sengAlarmMessage();
    }

    private void sengAlarmMessage() {
        try {
            log.info("--sengAlarmMessage--");
            TimeInterval timer = DateUtil.timer();
            while (NettyMessageQueue.getNettyMessageQueue().size()>0 && timer.interval() < 100000){
                String msg = NettyMessageQueue.getNettyMessageQueue().consume();
                log.info("剩余报警消息令总数:{}",NettyMessageQueue.getNettyMessageQueue().size());
                groupNettyClient.sendMessage(msg);
            }
        } catch (Exception e) {
            log.error("发送报警消息失败",e);
        }
    }

}
